tcpip

package
v0.0.0-...-7a82295 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 31, 2020 License: Apache-2.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var ErrBadLinkEndpoint = errors.New("bad link layer endpoint")
var ErrDuplicateNICID = errors.New("duplicate nic id")
var ErrNoRoute = errors.New("no route")
var ErrNotSupported = errors.New("operation not supported")
var ErrUnknownNICID = errors.New("unknown nic id")
var ErrUnknownProtocol = errors.New("unknown protocol")
var ErrWouldBlock = errors.New("operation would block")

Functions

This section is empty.

Types

type Address

type Address string

type FullAddress

type FullAddress struct {
	Addr Address
	Port uint16
	NIC  NICID
}

type LinkEndpointID

type LinkEndpointID uint64

type NICID

type NICID int32

type NetworkProtocolNumber

type NetworkProtocolNumber uint32

type Route

type Route struct {
	// Destination is the address that must be matched against the masked
	// target address to check if this row is viable.
	Destination Address

	// Mask specifies which bits of the Destination and the target address
	// must match for this row to be viable.
	Mask Address

	// Gateway is the gateway to be used if this row is viable.
	Gateway Address

	// NIC is the id of the nic to be used if this row is viable.
	NIC NICID
}

func (*Route) Match

func (r *Route) Match(addr Address) bool

type TransportProtocolNumber

type TransportProtocolNumber uint32

Directories

Path Synopsis
network
transport
udp

Jump to