Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrBadLinkEndpoint = errors.New("bad link layer endpoint")
var ErrDuplicateNICID = errors.New("duplicate nic id")
var ErrNoRoute = errors.New("no route")
var ErrNotSupported = errors.New("operation not supported")
var ErrUnknownNICID = errors.New("unknown nic id")
var ErrUnknownProtocol = errors.New("unknown protocol")
var ErrWouldBlock = errors.New("operation would block")
Functions ¶
This section is empty.
Types ¶
type FullAddress ¶
type LinkEndpointID ¶
type LinkEndpointID uint64
type NetworkProtocolNumber ¶
type NetworkProtocolNumber uint32
type Route ¶
type Route struct {
// Destination is the address that must be matched against the masked
// target address to check if this row is viable.
Destination Address
// Mask specifies which bits of the Destination and the target address
// must match for this row to be viable.
Mask Address
// Gateway is the gateway to be used if this row is viable.
Gateway Address
// NIC is the id of the nic to be used if this row is viable.
NIC NICID
}
type TransportProtocolNumber ¶
type TransportProtocolNumber uint32
Click to show internal directories.
Click to hide internal directories.